package TableDataBundle::Lingua::Word::EN::Adverb;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2021-06-01'; # DATE
our $DIST = 'TableDataBundle-Lingua-Word-EN-Adverb'; # DIST
our $VERSION = '0.002'; # VERSION

1;
# ABSTRACT: Collection of TableData:: modules that contain English adverbs

__END__

=pod

=encoding UTF-8

=head1 NAME

TableDataBundle::Lingua::Word::EN::Adverb - Collection of TableData:: modules that contain English adverbs

=head1 VERSION

This document describes version 0.002 of TableDataBundle::Lingua::Word::EN::Adverb (from Perl distribution TableDataBundle-Lingua-Word-EN-Adverb), released on 2021-06-01.

=head1 DESCRIPTION

This distribution contains the following L<TableData>:: modules:

=over

=item * L<TableData::Lingua::Word::EN::Adverb::TalkEnglish>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/TableDataBundle-Lingua-Word-EN-Adverb>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-TableDataBundle-Lingua-Word-EN-Adverb>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=TableDataBundle-Lingua-Word-EN-Adverb>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<TableData>

L<TableDataBundle::Lingua::Word::EN::Noun>,
L<TableDataBundle::Lingua::Word::EN::Adjective>.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2021 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
